Method: Aws::Keyspaces::Types::AutoScalingSettings#scaling_policy

Defined in:
lib/aws-sdk-keyspaces/types.rb

#scaling_policyTypes::AutoScalingPolicy

Amazon Keyspaces supports the ‘target tracking` auto scaling policy. With this policy, Amazon Keyspaces auto scaling ensures that the table’s ratio of consumed to provisioned capacity stays at or near the target value that you specify. You define the target value as a percentage between 20 and 90.



130
131
132
133
134
135
136
137
# File 'lib/aws-sdk-keyspaces/types.rb', line 130

class AutoScalingSettings < Struct.new(
  :auto_scaling_disabled,
  :minimum_units,
  :maximum_units,
  :scaling_policy)
  SENSITIVE = []
  include Aws::Structure
end