Class: Aws::Keyspaces::Types::TagResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-keyspaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the Amazon Keyspaces resource to which to add tags.

Returns:

  • (String)


1992
1993
1994
1995
1996
1997
# File 'lib/aws-sdk-keyspaces/types.rb', line 1992

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags to be assigned to the Amazon Keyspaces resource.

Returns:



1992
1993
1994
1995
1996
1997
# File 'lib/aws-sdk-keyspaces/types.rb', line 1992

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end