Class: Aws::Keyspaces::Types::UntagResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-keyspaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Keyspaces resource that the tags will be removed from. This value is an Amazon Resource Name (ARN).

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-keyspaces/types.rb', line 2086

class UntagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of existing tags to be removed from the Amazon Keyspaces resource.

Returns:



2086
2087
2088
2089
2090
2091
# File 'lib/aws-sdk-keyspaces/types.rb', line 2086

class UntagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end