Class: Aws::Keyspaces::Types::WarmThroughputSpecificationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Keyspaces::Types::WarmThroughputSpecificationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-keyspaces/types.rb
Overview
Contains the current warm throughput settings for a table, including the configured capacity units and the current status of the warm throughput configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#read_units_per_second ⇒ Integer
The number of read capacity units per second currently configured for warm throughput.
-
#status ⇒ String
The current status of the warm throughput configuration.
-
#write_units_per_second ⇒ Integer
The number of write capacity units per second currently configured for warm throughput.
Instance Attribute Details
#read_units_per_second ⇒ Integer
The number of read capacity units per second currently configured for warm throughput.
2439 2440 2441 2442 2443 2444 2445 |
# File 'lib/aws-sdk-keyspaces/types.rb', line 2439 class WarmThroughputSpecificationSummary < Struct.new( :read_units_per_second, :write_units_per_second, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the warm throughput configuration. Valid values are ‘AVAILABLE` when the configuration is active, and `UPDATING` when changes are being applied.
2439 2440 2441 2442 2443 2444 2445 |
# File 'lib/aws-sdk-keyspaces/types.rb', line 2439 class WarmThroughputSpecificationSummary < Struct.new( :read_units_per_second, :write_units_per_second, :status) SENSITIVE = [] include Aws::Structure end |
#write_units_per_second ⇒ Integer
The number of write capacity units per second currently configured for warm throughput.
2439 2440 2441 2442 2443 2444 2445 |
# File 'lib/aws-sdk-keyspaces/types.rb', line 2439 class WarmThroughputSpecificationSummary < Struct.new( :read_units_per_second, :write_units_per_second, :status) SENSITIVE = [] include Aws::Structure end |