Class: Aws::Keyspaces::Types::TagResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Keyspaces::Types::TagResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-keyspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Keyspaces resource to which to add tags.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the Amazon Keyspaces resource.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Keyspaces resource to which to add tags.
1992 1993 1994 1995 1996 1997 |
# File 'lib/aws-sdk-keyspaces/types.rb', line 1992 class TagResourceRequest < Struct.new( :resource_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the Amazon Keyspaces resource.
1992 1993 1994 1995 1996 1997 |
# File 'lib/aws-sdk-keyspaces/types.rb', line 1992 class TagResourceRequest < Struct.new( :resource_arn, :tags) SENSITIVE = [] include Aws::Structure end |