Class: Aws::Keyspaces::Types::UntagResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Keyspaces::Types::UntagResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-keyspaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Keyspaces resource that the tags will be removed from.
-
#tags ⇒ Array<Types::Tag>
A list of existing tags to be removed from the Amazon Keyspaces resource.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Keyspaces resource that the tags will be removed from. This value is an Amazon Resource Name (ARN).
2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-keyspaces/types.rb', line 2086 class UntagResourceRequest < Struct.new( :resource_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of existing tags to be removed from the Amazon Keyspaces resource.
2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-keyspaces/types.rb', line 2086 class UntagResourceRequest < Struct.new( :resource_arn, :tags) SENSITIVE = [] include Aws::Structure end |